// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "scene/Scene.hpp"
#include "scene/components/PlayerController.hpp"
#include "scene/components/GameCamera.hpp"
#include "scene/components/physics/3d/CubeCollider.hpp"
#include "scene/components/GameCamera.hpp"

namespace Dawn {
  class HelloWorldScene : public Scene {
    protected:
      Camera *camera;

      void stage() override {
        camera = Camera::create(this);
        camera->transform->lookAt(glm::vec3(0, 0, 8), glm::vec3(0, 0, 0));
        auto gameCamera = camera->item->addComponent<GameCamera>();

        auto playerItem = this->createSceneItem();
        auto player = playerItem->addComponent<PlayerController>();
        auto hitbox = playerItem->addComponent<CubeCollider>();

        auto wall = this->createSceneItem();
        auto wallHitbox = wall->addComponent<CubeCollider>();
        wall->transform.setLocalPosition(glm::vec3(-10, 0, 0));
        wallHitbox->min = -(wallHitbox->max = glm::vec3(1, 1, 5));

        gameCamera->player = player;
      }
      
      std::vector<Asset*> getRequiredAssets() override {
        auto assMan = &this->game->assetManager;
        std::vector<Asset*> assets;
        return assets;
      }

    public:
      HelloWorldScene(DawnGame *game) : Scene(game) {}
  };
}